@@ -27,6 +27,10 @@ L<IO::Handle|SPVM::IO::Handle>.
 
   has stream : Sys::IO::FileStream;
 
+=head2 input_line_number
+
+  has input_line_number : long;
+
 =head1 Class Methods
 
 =head2 new
@@ -121,19 +125,41 @@ Gets the file descriptor of L</"stream"> field.
 
   method read : int ($string : mutable string, $length : int = -1, $offset : int = 0);
 
-=head2 truncate
+=head2 printflush
 
-  method truncate : int ($legnth : long);
+  method printflush : int ($string : string);
 
-Truncates to a size of precisely length bytes.
+=head2 getline
 
-=head2 stat
+  method getline : string ();
 
-  method stat : Sys::IO::Stat ();
+=head2 getlines
 
-=head2 sync
+  method getlines : string ();
 
-  method sync : int ();
+=head2 flush
+
+  method flush : int ();
+
+=head2 ungetc
+
+  method ungetc : int ($c : int);
+
+=head2 clearerr
+
+  method clearerr : void ();
+
+=head2 error
+
+  method error : int ();
+
+=head2 getc
+
+  method getc : int ();
+
+=head2 eof
+
+  method eof : int ();
 
 =head1 See Also
 
